==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkDijkstraGraphGeodesicPath.java <==
// java wrapper for vtkDijkstraGraphGeodesicPath object
//

package vtk;
import vtk.*;

public class vtkDijkstraGraphGeodesicPath extends vtkGraphGeodesicPath
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetIdList_2();
  public vtkIdList GetIdList() {
    long temp = GetIdList_2();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetStopWhenEndReached_3(int id0);
  public void SetStopWhenEndReached(int id0)
    { SetStopWhenEndReached_3(id0); }

  private native int GetStopWhenEndReached_4();
  public int GetStopWhenEndReached()
    { return GetStopWhenEndReached_4(); }

  private native void StopWhenEndReachedOn_5();
  public void StopWhenEndReachedOn()
    { StopWhenEndReachedOn_5(); }

  private native void StopWhenEndReachedOff_6();
  public void StopWhenEndReachedOff()
    { StopWhenEndReachedOff_6(); }

  private native void SetUseScalarWeights_7(int id0);
  public void SetUseScalarWeights(int id0)
    { SetUseScalarWeights_7(id0); }

  private native int GetUseScalarWeights_8();
  public int GetUseScalarWeights()
    { return GetUseScalarWeights_8(); }

  private native void UseScalarWeightsOn_9();
  public void UseScalarWeightsOn()
    { UseScalarWeightsOn_9(); }

  private native void UseScalarWeightsOff_10();
  public void UseScalarWeightsOff()
    { UseScalarWeightsOff_10(); }

  private native void SetRepelPathFromVertices_11(int id0);
  public void SetRepelPathFromVertices(int id0)
    { SetRepelPathFromVertices_11(id0); }

  private native int GetRepelPathFromVertices_12();
  public int GetRepelPathFromVertices()
    { return GetRepelPathFromVertices_12(); }

  private native void RepelPathFromVerticesOn_13();
  public void RepelPathFromVerticesOn()
    { RepelPathFromVerticesOn_13(); }

  private native void RepelPathFromVerticesOff_14();
  public void RepelPathFromVerticesOff()
    { RepelPathFromVerticesOff_14(); }

  private native void SetRepelVertices_15(vtkPoints id0);
  public void SetRepelVertices(vtkPoints id0)
    { SetRepelVertices_15(id0); }

  private native long GetRepelVertices_16();
  public vtkPoints GetRepelVertices() {
    long temp = GetRepelVertices_16();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetCumulativeWeights_17(vtkDoubleArray id0);
  public void GetCumulativeWeights(vtkDoubleArray id0)
    { GetCumulativeWeights_17(id0); }

  public vtkDijkstraGraphGeodesicPath() { super(); }

  public vtkDijkstraGraphGeodesicPath(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkDijkstraGraphGeodesicPath.java <==
// java wrapper for vtkDijkstraGraphGeodesicPath object
//

package vtk;
import vtk.*;

public class vtkDijkstraGraphGeodesicPath extends vtkGraphGeodesicPath
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetIdList_2();
  public vtkIdList GetIdList() {
    long temp = GetIdList_2();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStopWhenEndReached_3(int id0);
  public void SetStopWhenEndReached(int id0)
    { SetStopWhenEndReached_3(id0); }

  private native int GetStopWhenEndReached_4();
  public int GetStopWhenEndReached()
    { return GetStopWhenEndReached_4(); }

  private native void StopWhenEndReachedOn_5();
  public void StopWhenEndReachedOn()
    { StopWhenEndReachedOn_5(); }

  private native void StopWhenEndReachedOff_6();
  public void StopWhenEndReachedOff()
    { StopWhenEndReachedOff_6(); }

  private native void SetUseScalarWeights_7(int id0);
  public void SetUseScalarWeights(int id0)
    { SetUseScalarWeights_7(id0); }

  private native int GetUseScalarWeights_8();
  public int GetUseScalarWeights()
    { return GetUseScalarWeights_8(); }

  private native void UseScalarWeightsOn_9();
  public void UseScalarWeightsOn()
    { UseScalarWeightsOn_9(); }

  private native void UseScalarWeightsOff_10();
  public void UseScalarWeightsOff()
    { UseScalarWeightsOff_10(); }

  private native void SetRepelPathFromVertices_11(int id0);
  public void SetRepelPathFromVertices(int id0)
    { SetRepelPathFromVertices_11(id0); }

  private native int GetRepelPathFromVertices_12();
  public int GetRepelPathFromVertices()
    { return GetRepelPathFromVertices_12(); }

  private native void RepelPathFromVerticesOn_13();
  public void RepelPathFromVerticesOn()
    { RepelPathFromVerticesOn_13(); }

  private native void RepelPathFromVerticesOff_14();
  public void RepelPathFromVerticesOff()
    { RepelPathFromVerticesOff_14(); }

  private native void SetRepelVertices_15(vtkPoints id0);
  public void SetRepelVertices(vtkPoints id0)
    { SetRepelVertices_15(id0); }

  private native long GetRepelVertices_16();
  public vtkPoints GetRepelVertices() {
    long temp = GetRepelVertices_16();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCumulativeWeights_17(vtkDoubleArray id0);
  public void GetCumulativeWeights(vtkDoubleArray id0)
    { GetCumulativeWeights_17(id0); }

  public vtkDijkstraGraphGeodesicPath() { super(); }

  public vtkDijkstraGraphGeodesicPath(long id) { super(id); }
  public native long   VTKInit();

}
